=======
surebet
=======


.. image:: https://img.shields.io/pypi/v/surebet.svg
        :target: https://pypi.python.org/pypi/surebet

.. image:: https://img.shields.io/travis/HintikkaKimmo/surebet.svg
        :target: https://travis-ci.org/HintikkaKimmo/surebet

.. image:: https://readthedocs.org/projects/surebet/badge/?version=latest
        :target: https://surebet.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/HintikkaKimmo/surebet/shield.svg
        :target: https://pyup.io/repos/github/HintikkaKimmo/surebet/
        :alt: Updates

.. image:: https://api.codeclimate.com/v1/badges/6150665607597692942e/maintainability
        :target: https://codeclimate.com/github/HintikkaKimmo/surebet/maintainability
        :alt: Maintainability

.. image:: https://api.codeclimate.com/v1/badges/6150665607597692942e/test_coverage
        :target: https://codeclimate.com/github/HintikkaKimmo/surebet/test_coverage
        :alt: Test Coverage


surebet is Python sport betting library allowing you to easily convert betting odds, calculate returns, calculate arbitrage betting opportunities and more


* Free software: MIT License
* Documentation: https://surebet.readthedocs.io.


Features
--------

* Normalize variety of betting odds to decimal odds available option below:

1. US odds to decimal odds (us_to_dec)
2. Probability odds to decimal odds (pro_to_dec)
3. HongKong odds to decimal odds (hk_to_dec)
4. Malaysian odds to decimal odds (mal_to_dec)
5. Indonesian odds to decimal odds (ind_to_dec)

* Identify there is arbitrage bet opportunity

* TODO

Quickstart
----------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
